# Generated by roxygen2: do not edit by hand

export(biv_brlmr_order)
export(biv_hazard_gradient)
export(biv_mean_residual)
export(biv_rhazard_gradient)
export(biv_rmrl)
export(biv_whr_order)
export(biv_wmrl_order)
export(biv_wrhr_order)
export(biv_wrmrl_order)
export(blt_order_residual)
export(blt_order_reversed)
export(blt_residual)
export(blt_residual_gumbel)
export(blt_reversed)
export(blt_reversed_fgm)
export(blt_reversed_power)
export(dbivpower)
export(dfgm_biv)
export(dgumbel_biv)
export(hazard_rate)
export(hr_order)
export(info_gen_function)
export(lt_residual)
export(lt_rl_order)
export(mean_residual)
export(mrl_order)
export(nbuhr_test)
export(np_blt_residual)
export(np_lt_residual)
export(pbivpower)
export(pfgm_biv)
export(pgumbel_biv)
export(plot_blt_residual)
export(plot_blt_reversed)
export(rbivpower)
export(rfgm_biv)
export(rgumbel_biv)
export(rschur_biv)
export(sbivpower)
export(sfgm_biv)
export(sgumbel_biv)
export(shannon_entropy)
export(sim_blt_residual)
export(sschur_biv)
