% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distributions.R
\name{schur_biv}
\alias{schur_biv}
\alias{sschur_biv}
\alias{rschur_biv}
\title{Schur-Constant Bivariate Distribution}
\usage{
sschur_biv(x1, x2, lambda = 1)

rschur_biv(n, lambda = 1)
}
\arguments{
\item{x1, x2}{Non-negative values.}

\item{lambda}{Exponential rate parameter for the generating survival function.}

\item{n}{Number of random observations.}
}
\value{
Numeric vector (\code{sschur_biv}) or two-column matrix
  (\code{rschur_biv}).
}
\description{
Random generation and survival function for a Schur-constant bivariate
distribution with survival function
\deqn{\bar{F}(x_1,x_2) = S(x_1 + x_2),\quad x_1,x_2 > 0,}
where \eqn{S} is a given univariate survival function.  The default marginal
is exponential with rate \code{lambda}.
}
\examples{
sschur_biv(0.5, 1, lambda = 1)
set.seed(2); head(rschur_biv(40, lambda = 1))

}
\references{
Barlow R.E., Mendel M.B. (1992). De Finetti-type representations for life
distributions. *Journal of the American Statistical Association*, 87(420),
1116--1122.
}
