% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bivariate_laplace_residual.R
\name{blt_residual_gumbel}
\alias{blt_residual_gumbel}
\title{Closed-Form Bivariate Laplace Transform of Residual Lives (Gumbel)}
\usage{
blt_residual_gumbel(s1, s2, t1 = 0, t2 = 0, k1 = 1, k2 = 1, theta = 0)
}
\arguments{
\item{s1, s2}{Positive Laplace parameters.}

\item{t1, t2}{Non-negative truncation ages.}

\item{k1, k2}{Positive rate parameters.}

\item{theta}{Non-negative association parameter.}
}
\value{
A named numeric vector \code{(L1_star, L2_star)}.
}
\description{
Returns the *star* bivariate Laplace transform of residual lives for the
Gumbel bivariate exponential distribution in closed form:
\deqn{L^*_{X_{t_1|t_2}}(s_1) = \frac{1}{k_1 + s_1 + \theta t_2},\quad
  L^*_{X_{t_2|t_1}}(s_2) = \frac{1}{k_2 + s_2 + \theta t_1}.}
}
\examples{
blt_residual_gumbel(s1 = 1, s2 = 1, t1 = 0.5, t2 = 0.5)
blt_residual_gumbel(s1 = 2, s2 = 0.5, t1 = 0, t2 = 1, k1 = 2, k2 = 1, theta = 0.3)

}
\references{
Jayalekshmi S., Rajesh G., Nair N.U. (2022), Example 3.1.
\doi{10.1080/03610926.2022.2085874}
}
\seealso{
\code{\link{blt_residual}}
}
